@@ -52,7 +52,7 @@ public:
     OrgKdeKorganizerCalendarInterface *interface();
 
 protected:
-    KParts::ReadOnlyPart *createPart() override;
+    KParts::Part *createPart() override;
 
 private Q_SLOTS:
     void slotNewJournal();
