@@ -50,7 +50,7 @@ KCMSDSummary::KCMSDSummary(QWidget *parent)
     connect(mDateMonthButton, &QRadioButton::clicked, this, &KCMSDSummary::modified);
     connect(mDateRangeButton, &QRadioButton::clicked, this, &KCMSDSummary::modified);
 
-    connect(mCustomDays, QOverload<int>::of(&QSpinBox::valueChanged), this,
+    connect(mCustomDays, qOverload<int>(&QSpinBox::valueChanged), this,
             &KCMSDSummary::modified);
     connect(mCustomDays, QOverload<int>::of(
                 &QSpinBox::valueChanged), this, &KCMSDSummary::customDaysChanged);
